@@ -1,25 +1,13 @@
-msg <- function(..., startup = FALSE) {
+msg <- function(x, startup = FALSE) {
   if (startup) {
     if (!isTRUE(getOption("tidyverse.quiet"))) {
-      packageStartupMessage(text_col(...))
+      rlang::inform(x, class = "packageStartupMessage")
     }
   } else {
-    message(text_col(...))
+    rlang::inform(x)
   }
 }
 
-text_col <- function(x) {
-  # If RStudio not available, messages already printed in black
-  if (!rstudioapi::isAvailable()) {
-    return(x)
-  }
-
-  theme <- rstudioapi::getThemeInfo()
-
-  if (theme$dark) crayon::white(x) else crayon::black(x)
-
-}
-
 #' List all packages in the tidyverse
 #'
 #' @param include_self Include tidyverse in the list?
@@ -30,12 +18,13 @@ tidyverse_packages <- function(include_self = TRUE) {
   raw <- utils::packageDescription("tidyverse")$Imports
   imports <- strsplit(raw, ",")[[1]]
   parsed <- gsub("^\\s+|\\s+$", "", imports)
+  names <- vapply(strsplit(parsed, "\\s+"), "[[", 1, FUN.VALUE = character(1))
 
   if (include_self) {
-    parsed <- c(parsed, "tidyverse")
+    names <- c(names, "tidyverse")
   }
 
-  parsed
+  names
 }
 
 invert <- function(x) {
